# Authors

- Tom Van Mele <<van.mele@arch.ethz.ch>> [@brgcode](https://github.com/brgcode)
- Vedad Alic <<vedad.alic@outlook.com>> [@vedadalic](https://github.com/vedadalic)
- Andrew Liew <<a.liew@sheffield.ac.uk>> [@andrewliew](https://github.com/andrewliew)
